class Piece:
    def __init__(self, sort, color, position):
        self.sort = sort
        self.color = color
        self.position = position

class Board:
    def __init__(self):
        self.position = {}

    def add(self, piece):
        valid = True

        if piece.sort == 'K':
            for p in self.position:
                if self.position[p].sort == 'K' and (self.position[p].color == piece.color):
                    valid = False
        else:
            for p in self.position:
                if self.same_position(p, piece.position):
                    valid = False

        if not valid:
            print('invalid query')
        else:
            self.position[piece.position] = piece

    def remove(self, position):
        valid = True
        found_position = None
        for p in self.position:
            if self.same_position(p, position) and self.position[p].sort == 'K':
                valid = False

            if self.same_position(p, position):
                found_position = p

        if valid and found_position != None:
            del self.position[found_position]
        else:
            print('invalid query')


    def move(self, piece, position):
        valid = True
        found = False
        for p in self.position:
            if self.same_position(position, p) and self.position[p].sort == 'P':
                self.position[p] = piece
                found = True
            
            if self.same_position(position, p) and self.position[p].sort == 'K':
                valid = False

        if valid and not found:
            self.position[position] = piece
        elif valid:
            print('invalid query')

    def is_mate(self, color):
        king = self.position[self.find_king(color)]

        for p in self.position:
            piece = self.position[p]
            if piece.sort != 'K' and piece.color != color and (abs(king.position[0] - p[0]) == 1 or abs(king.position[1] - p[1]) == 1):
                return True

        return False


    def find_king(self, color):
        for p in self.position:
            if self.position[p].color == color and self.position[p].sort == 'K':
                return p
    
    def same_position(self, p1, p2):
        return p1[0] == p2[0] and p1[1] == p2[1]

    def find_piece(self, position):
        for p in self.position:
            if self.same_position(position, p):
                return self.position[p]

def get_position():
    x = int(input('Enter x = '))
    y = int(input('Enter y = '))

    return (x, y)

# Create White King
w_position = (-10, -10)
w_king = Piece('K', 'white', w_position)

# Create Black King
b_position = (10, 10)
b_king = Piece('K', 'black', b_position)

# Add Kings to Board
board = Board()
board.add(w_king)
board.add(b_king)

# White Start the Game
turn = True


while not board.is_mate('white') or not board.is_mate('black'):
    # when turn is True, it's white's turn

    color = 'white'
    if turn:
        print('White Turn')
    else:
        print('Black Turn')
        color = 'black'
    turn = not turn

    print('1) Add Soldier')
    print('2) Remove Soldier')
    print('3) Move Soldier')

    choice = int(input())

    if choice == 1:
        new_soldier = Piece('S', color, get_position())
        board.add(new_soldier)
    elif choice == 2:
        board.remove(get_position())
    else:
        print('Old Position')
        old_position = get_position()
        piece = board.find_piece(old_position)

        if piece == None:
            print('invalid query')
            continue

        print('New Position')
        new_position = get_position()

        board.move(piece, new_position)


print('Game Over!')
if board.is_mate('black'):
    print('Black Won')
else:
    print('White Won')